@@ -351,6 +351,7 @@ void
 terminal_widget_set_background_transparent (GtkWidget *widget,
 					    gboolean   setting)
 {
+    /* FIXME: Don't enable this if we have a compmgr. */
   vte_terminal_set_background_transparent(VTE_TERMINAL(widget), setting);
 }
 
@@ -363,6 +364,14 @@ terminal_widget_set_background_darkness (GtkWidget *widget,
   vte_terminal_set_background_saturation(VTE_TERMINAL(widget), 1.0 - factor);
 }
 
+void
+terminal_widget_set_background_opacity (GtkWidget *widget,
+					double     factor)
+{
+  g_return_if_fail(VTE_IS_TERMINAL(widget));
+  vte_terminal_set_opacity(VTE_TERMINAL(widget), factor * 0xffff);
+}
+
 void
 terminal_widget_set_background_scrolls (GtkWidget *widget,
 					gboolean   setting)
@@ -600,27 +609,30 @@ terminal_widget_write_data_to_child (GtkWidget  *widget,
 
 void
 terminal_widget_set_pango_font (GtkWidget                  *widget,
-                                const PangoFontDescription *font_desc,
+				const PangoFontDescription *font_desc,
 				gboolean no_aa_without_render)
 {
-  Display *dpy;
-  gboolean has_render;
-  int event_base, error_base;
-  
   g_return_if_fail (font_desc != NULL);
 
-  dpy = gdk_x11_display_get_xdisplay(gdk_display_get_default());
+  if (!no_aa_without_render)
+    vte_terminal_set_font (VTE_TERMINAL (widget), font_desc);
 
-  has_render = (XRenderQueryExtension (dpy, &event_base, &error_base) &&
-                 (XRenderFindVisualFormat (dpy, DefaultVisual (dpy, DefaultScreen (dpy))) != 0));
+  else
+    {
+      Display *dpy;
+      gboolean has_render;
+      gint event_base, error_base;
 
-  if (has_render || !no_aa_without_render) 
-    {
-      vte_terminal_set_font (VTE_TERMINAL (widget), font_desc);
-    } 
-  else 
-    {
-      vte_terminal_set_font_full (VTE_TERMINAL (widget), font_desc, VTE_ANTI_ALIAS_FORCE_DISABLE);
+      dpy = gdk_x11_display_get_xdisplay (gdk_display_get_default ());
+      has_render = (XRenderQueryExtension (dpy, &event_base, &error_base) &&
+		    (XRenderFindVisualFormat (dpy, DefaultVisual (dpy, DefaultScreen (dpy))) != 0));
+
+      if (has_render)
+	vte_terminal_set_font (VTE_TERMINAL (widget), font_desc);
+      else 
+	vte_terminal_set_font_full (VTE_TERMINAL (widget),
+				    font_desc,
+				    VTE_ANTI_ALIAS_FORCE_DISABLE);
     }
 }
 
